﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Utilities;

namespace Dienstfahrten.Klassen
{
    class Mail
    {

        public string mailTo { get; set; }
        public string subject { get; set; }
        public string body { get; set; }

        private SPWeb _currentWeb;
        private Konfiguration _konf { get; set; }
        private List<Object> _dl { get; set; }
        private bool _htmlTags;
        private bool _htmlencode;

        /// <summary>
        /// Konstruktor für selbst definierte Mails
        /// </summary>
        /// <param name="web"></param>
        /// <param name="konf"></param>
        /// <param name="dl"></param>
        /// <param name="htmlTags"></param>
        /// <param name="htmlencode"></param>
        public Mail(SPWeb web, Konfiguration konf, List<Object> dl, bool htmlTags, bool htmlencode)
        {
            this._currentWeb = web;
            this._htmlTags = htmlTags;
            this._htmlencode = htmlencode;
            this._dl = dl;
            this._konf = konf;
        }

        /// <summary>
        /// Konstruktor für in dieser Klasse definierte Mails
        /// </summary>
        /// <param name="web"></param>
        /// <param name="konf"></param>
        /// <param name="dl"></param>
        public Mail(SPWeb web, Konfiguration konf, List<Object> dl)
        {
            this._currentWeb = web;
            this._dl = dl;
            this._konf = konf;
        }

        /// <summary>
        /// Sendet die in dieser Klasse definierte Mail
        /// </summary>
        /// <returns></returns>
        public bool createAndSendMail()
        {
            this.createMailTo();
            this.createSubject();
            this.createBody(); //setzt htmlTags und htmlencode

            return SPUtility.SendEmail(_currentWeb, _htmlTags, _htmlencode, mailTo, subject, body);
        }

        /// <summary>
        /// Sende Eine Mail anhand der zuvor definierten Inhalte
        /// </summary>
        /// <returns></returns>
        public bool sendMail()
        {
           return SPUtility.SendEmail(_currentWeb, _htmlTags, _htmlencode, mailTo, subject, body);
        }


        /// <summary>
        /// Generiert einen Betreff anhand der Benutzerdaten
        /// </summary>
        /// <returns></returns>
        public string createSubject() {
            if(_konf != null)
                this.subject = "Dienstfahrtabrechnung von " + _konf.Benutzer.Name + " vom " + DateTime.Now.ToString("dd.MM.yyyy");
            else this.subject = string.Empty;

            return this.subject;
        }

        /// <summary>
        /// Erstellt die Empfängerliste anhand er Benutzerdaten
        /// </summary>
        /// <returns></returns>
        public string createMailTo()
        {
            if(_konf != null) 
            {
                this.mailTo = _konf.Empfaenger.Email + ";";
                if (_konf.Kopie)
                    this.mailTo += _konf.Benutzer.Email + ";";
                return this.mailTo;
            }
            else {
                return mailTo = string.Empty;
            }
        }

        /// <summary>
        /// Erstellt den Emailtext anhand der übergebnen Dienstfahrtliste
        /// </summary>
        /// <returns></returns>
        public string createBody()
        {
            _htmlTags = true;
            _htmlencode = false;

            body =
            "<html><head>" +
            "<style type=\"text/css\">" +
            "    body {" +
            "        background-color: #fff;" +
            "        color: #444;" +
            "        font-size: 12px;" +
            "        font-family: Arial, Helvetica, sans-serif;" +
            "    }" +
            "    table{" +
            "        /* width: 100%; */" +
            "        color: #444;" +
            "        font-size: 12px;" +
            "    }" +
            "    th{" +
            "        border-bottom: 1px solid #787878;" +
            "        padding: 2px 3px 2px 3px;" +
            "        color: #1d577e;" +
            "        text-align: left;" +
            "        font-weight: bold;" +
            "    }" +
            "    .ueberschrift{" +
            "        padding: 2px 3px 2px 3px;" +
            "        color: #1d577e;" +
            "        text-align: left;" +
            "        font-weight: bold;" +
            "    }" +
            "    .contentWrapper, .header{" +
            "        width: 958px;" +
            "        padding-left: 10px;" +
            "        padding-top: 10px;" +
            "    }" +
            "        </style>" +
            "        <title>Dienstfahrten&uuml;bersicht für " + _konf.Vorname + " " + _konf.Nachname + "</title>" +
            "</head>" +
            "<body>" +
            "    <div class=\"wrapper\">" +
            "        <div class=\"header\">" +
            "            <div class=\"headerText\">" +
            "	            <h2>Dienstfahrten&uuml;bersicht für: <span style=\"font-style: italic;\">" + _konf.Vorname + " " + _konf.Nachname + "</span></h2><br>" +
            "            </div>" +
            "        </div>" +
            "        <div class=\"contentWrapper\">" +
            "            <table>" +
            "	            <tr><td class=\"ueberschrift\">Name:</td><td>" + _konf.Vorname + " " + _konf.Nachname + "</td></tr>" +
            "	            <tr><td class=\"ueberschrift\">Personalnummer:</td><td>" + _konf.PersonalNummer + "</td></tr>" +
            "	            <tr><td class=\"ueberschrift\">Abteilung:</td><td>" + _konf.Abteilung + "</td></tr>";
            if (_konf.Auftragsnummer != string.Empty && _konf.Auftragsnummer != null) body +=
            "	            <tr><td class=\"ueberschrift\">Auftragsnummer:</td><td>" + _konf.Auftragsnummer + "</td></tr>";
            if (_konf.StrasseNummer != string.Empty && _konf.StrasseNummer != null) body +=
            "	            <tr><td class=\"ueberschrift\">Adresse:</td><td>" + _konf.StrasseNummer + "</td></tr>";
            if (_konf.PLZ != 0) body +=
            "	            <tr><td class=\"ueberschrift\">&nbsp;</td><td>" + _konf.PLZ + " " + _konf.Ort + "</td></tr>";
            if (_konf.Bank != string.Empty && _konf.Bank != null && _konf.BLZ != 0 && _konf.KtoNr != 0) body +=
            "	            <tr><td class=\"ueberschrift\">&nbsp;</td><td>&nbsp;</td></tr>" +
            "	            <tr><td class=\"ueberschrift\">Bank:</td><td>" + _konf.Bank + "</td></tr>" +
            "	            <tr><td class=\"ueberschrift\">BLZ:</td><td>" + _konf.BLZ + "</td></tr>" +
            "	            <tr><td class=\"ueberschrift\">Kontonummer:</td><td  >" + _konf.KtoNr + "</td></tr>";
            body +=
            "           </table>" +
			"            <br /><br />" +
			"            <table style=\"width: 700px;\">" +
			"	            <tr>" +
			"	            <th width=\"100px\">Datum<br /></th>" +
			"	            <th width=\"200px\">Von<br /></th>" +
			"	            <th width=\"200px\">Nach<br /></th>" +
			"	            <th width=\"100px\">Strecke<br />(einfach)</th>" +
			"	            <th width=\"100px\">Strecke<br />(gesamt)</th>" +
			"	            </tr>";
            
            int summe = 0;
            foreach (Dienstfahrt df in _dl)
            {
                body += "<tr>" +
                 "<td>" + df.Datum.GetValueOrDefault().ToString("dd.MM.yyyy") + "</td>" +
                 "<td>" + df.Von + "</td>" +
                 "<td>" + df.Nach + "</td>" +
                 "<td>" + df.Einfach + " km</td>" +
                 "<td>" + df.Gesamt.ToString() + " km</td>" +
                 "</tr>";
                summe += df.Gesamt;
            }

            body += 
			"            </table>" +
			"            <table style=\"font-family: Arial, Times, serif; width: 700px;\">" +
			"	            <tr>" +
			"	            <th width=\"600px\" colspan=\"5\">&nbsp;</th>" +
			"	            </tr>" +
			"	            <tr>" +
            "	            <td width=\"100px\" colspan=\"4\" style=\"text-align: right;\">Summierte Strecke: &nbsp;&nbsp;</td>" +
			"	            <td width=\"100px\"><strong>" + summe.ToString() + " km</strong></td>" +
			"	            </tr>" +
			"            </table>" +     
		    "        </div>" +
	        "    </div>" +
	        "    </body>" +
            "</html>";

            return body;
        }
    }
}
